@@ -21,15 +21,15 @@ def print_missings(df):
     --------------------
     Examples:
 
-    # import dependecies
+    # import dependencies
     import pandas as pd
     import numpy as np
 
     # create data frame
     data = {'age': [27, np.nan, 30, 25, np.nan], 
-        'height': [170, 168, 173, 177, 165], 
-        'gender': ['female', 'male', np.nan, 'male', 'female'],
-        'income': ['high', 'medium', 'low', 'low', 'no income']}
+            'height': [170, 168, 173, 177, 165], 
+            'gender': ['female', 'male', np.nan, 'male', 'female'],
+            'income': ['high', 'medium', 'low', 'low', 'no income']}
     df = pd.DataFrame(data)
 
     # count missings
@@ -38,10 +38,10 @@ def print_missings(df):
     '''
 
     # count missing values
-    total = df.isnull().sum().sort_values(ascending = False)
+    total   = df.isnull().sum().sort_values(ascending = False)
     percent = (df.isnull().sum() / df.isnull().count()).sort_values(ascending = False)
-    table = pd.concat([total, percent], axis = 1, keys = ['Total', 'Percent'])
-    table = table[table['Total'] > 0]
+    table   = pd.concat([total, percent], axis = 1, keys = ['Total', 'Percent'])
+    table   = table[table['Total'] > 0]
 
     # return results
     if len(table) > 0:
@@ -64,10 +64,10 @@ import pandas as pd
 
 def fill_missings(df, 
                   to_unknown_cols = [], 
-                  to_0_cols = [], 
-                  to_mean_cols = [],
-                  to_true_cols = [], 
-                  to_false_cols = []):
+                  to_0_cols       = [], 
+                  to_mean_cols    = [],
+                  to_true_cols    = [], 
+                  to_false_cols   = []):
     '''
     Replaces NA in the dataset with specific values.
     
@@ -104,7 +104,7 @@ def fill_missings(df,
 
     if len(to_false_cols) > 0:
         df_new[to_false_cols] = df_new[to_false_cols].fillna(False)
-       
+    
     # return results
     return df_new
 
@@ -140,14 +140,14 @@ def split_nested_features(df,
     --------------------
     Examples:
 
-    # import dependecies
+    # import dependencies
     import pandas as pd
     import numpy as np
 
     # create data frame
     data = {'age': [27, np.nan, 30, 25, np.nan], 
-        'height': [170, 168, 173, 177, 165], 
-        'income': ['high,100', 'medium,50', 'low,25', 'low,28', 'no income,0']}
+            'height': [170, 168, 173, 177, 165], 
+            'income': ['high,100', 'medium,50', 'low,25', 'low,28', 'no income,0']}
     df = pd.DataFrame(data)
 
     # split nested features
@@ -212,7 +212,7 @@ def print_factor_levels(df, top = 5):
     --------------------
     Examples:
 
-    # import dependecies
+    # import dependencies
     import pandas as pd
     import numpy as np
 
@@ -243,4 +243,68 @@ def print_factor_levels(df, top = 5):
             print('-' * 30)
             print('')
     else:
-        print('Found no categorical features.')
\ No newline at end of file
+        print('Found no categorical features.')
+
+
+
+###############################
+#                             
+#      CORRECT COLUMN NAMES
+#                             
+###############################
+
+import pandas as pd
+import re
+
+def correct_colnames(df):
+    '''
+    Corrects column names to avoid modeling errors:
+    - drops foreign symbols
+    - ensures that column names are unique
+    
+    --------------------
+    Arguments:
+    - df (pandas DF): dataset
+
+    --------------------
+    Returns
+    - pandas DF with corrected column names
+
+    --------------------
+    Examples:
+
+    # import dependencies
+    import pandas as pd
+    import numpy as np
+
+    # create data frame
+    data = {'age': [27, np.nan, 30, 25, np.nan], 
+            'height': [170, 168, 173, 177, 165], 
+            'height': ['female', 'male', np.nan, 'male', 'female'],
+            'income': ['high', 'medium', 'low', 'low', 'no income']}
+    df = pd.DataFrame(data)
+    df.columns = ['age', 'height', 'height', 'income']
+
+    # correct column names
+    from dptools import correct_colnames
+    df_new = correct_colnames(df)
+    '''
+
+    # drop foreign symbols
+    df_new = df.rename(columns = lambda x: re.sub('[^A-Za-z0-9_]+', '', x))
+
+    # ensure that all colnames are unique
+    def uniquify(df_columns):
+        seen = set()
+        for item in df_columns:
+            fudge = 1
+            newitem = item
+            while newitem in seen:
+                fudge += 1
+                newitem = '{}_{}'.format(item, fudge)
+            yield newitem
+            seen.add(newitem)
+    df_new.columns = uniquify(df_new)
+
+    # return results
+    return df_new
\ No newline at end of file
